@@ -12,21 +12,6 @@ use Archive::Tar;
 use Cwd;
 
 
-=head1 NAME
-
-Archive::Any::Tar - Archive::Any wrapper around Archive::Tar
-
-=head1 SYNOPSIS
-
-B<DO NOT USE THIS MODULE DIRECTLY>
-
-Use Archive::Any instead.
-
-=head1 DESCRIPTION
-
-Wrapper around Archive::Tar for Archive::Any.
-
-=cut
 
 sub new {
     my($class, $file) = @_;
@@ -73,6 +58,35 @@ sub type {
 }
 
 
+
+1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Archive::Any::Tar
+
+=head1 VERSION
+
+version 0.0940
+
+=head1 SYNOPSIS
+
+B<DO NOT USE THIS MODULE DIRECTLY>
+
+Use Archive::Any instead.
+
+=head1 DESCRIPTION
+
+Wrapper around Archive::Tar for Archive::Any.
+
+=head1 NAME
+
+Archive::Any::Tar - Archive::Any wrapper around Archive::Tar
+
 =head1 AUTHOR
 
 Michael G Schwern E<lt>schwern@pobox.comE<gt>
@@ -81,6 +95,29 @@ Michael G Schwern E<lt>schwern@pobox.comE<gt>
 
 Archive::Any, Archive::Tar
 
-=cut
+=head1 AUTHORS
 
-1;
+=over 4
+
+=item *
+
+Clint Moore
+
+=item *
+
+Michael G Schwern (author emeritus)
+
+=item *
+
+Olaf Alders (current maintainer)
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Olaf Alders.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
